==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/moocho/test/DenseLinAlgPack/TestDenseLinAlgPackMain.cpp <==
// @HEADER
// ***********************************************************************
// 
// Moocho: Multi-functional Object-Oriented arCHitecture for Optimization
//                  Copyright (2003) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Roscoe A. Bartlett (rabartl@sandia.gov) 
// 
// ***********************************************************************
// @HEADER
#include <iostream>

#include "DenseLinAlgPack_TestDenseLinAlgPack.hpp"

int main() {

//	DenseLinAlgPack::TestingPack::TestVectorBasicOp(std::cout);
//	DenseLinAlgPack::TestingPack::TestGenMatrixBasicOp(std::cout);
//	DenseLinAlgPack::TestingPack::TestDenseLinAlgPackIO(std::cin,std::cout);
//	DenseLinAlgPack::TestingPack::TestPivotVecMat(std::cout);
  bool result = DenseLinAlgPack::TestingPack::TestDenseLinAlgPack( &std::cout );
  if(result)
    std::cerr << "DenseLinAlgPack checks out!\n";
  else
    std::cerr << "Oops!  At least one of the tests for DenseLinAlgPack failed!\n";
  return ( result == true ? 0 : -1 );
}

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/moocho/test/DenseLinAlgPack/TestDenseLinAlgPackMain.cpp <==
// @HEADER
// ***********************************************************************
// 
// Moocho: Multi-functional Object-Oriented arCHitecture for Optimization
//                  Copyright (2003) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Roscoe A. Bartlett (rabartl@sandia.gov) 
// 
// ***********************************************************************
// @HEADER


#include <iostream>

#include "DenseLinAlgPack_TestDenseLinAlgPack.hpp"
#include "Teuchos_GlobalMPISession.hpp"
#include "Teuchos_StandardCatchMacros.hpp"

int main(int argc, char* argv[]) {

  bool success = true;

  Teuchos::GlobalMPISession mpiSession(&argc,&argv);

  try {

    const bool result = DenseLinAlgPack::TestingPack::TestDenseLinAlgPack( &std::cout );
    if (!result) success = false;

  } // end try
  TEUCHOS_STANDARD_CATCH_STATEMENTS(true, std::cerr, success);
  
  if(success)
    std::cout << "\nEnd Result: TEST PASSED" << std::endl;
    
  return success == true ? 0 : 1;

}
